@@ -43,7 +43,7 @@ public:
     POP3Protocol(const QByteArray &pool, const QByteArray &app, bool SSL);
     ~POP3Protocol() override;
 
-    virtual void setHost(const QString &host, quint16 port, const QString &user, const QString &pass) override;
+    void setHost(const QString &host, quint16 port, const QString &user, const QString &pass) override;
 
     void get(const QUrl &url) override;
     void stat(const QUrl &url) override;
