@@ -30,13 +30,8 @@ public:
     typedef QSharedPointer<MessageHelper> Ptr;
 
     virtual ~MessageHelper();
-    virtual Akonadi::Item createItemFromMessage(const KMime::Message::Ptr &message,
-            const qint64 uid,
-            const qint64 size,
-            const QMap<QByteArray, QVariant> &attrs,
-            const QList<QByteArray> &flags,
-            const KIMAP::FetchJob::FetchScope &scope,
-            bool &ok) const;
+    virtual Akonadi::Item createItemFromMessage(const KMime::Message::Ptr &message, const qint64 uid, const qint64 size, const QMap<QByteArray, QVariant> &attrs, const QList<QByteArray> &flags,
+                                                const KIMAP::FetchJob::FetchScope &scope, bool &ok) const;
 };
 
 #endif
