@@ -1,5 +1,4 @@
 #include <QDataStream>
-#include <QDebug>
 #include "debug.h"
 
 #include "o2/o0baseauth.h"
@@ -8,7 +7,7 @@
 
 static const quint16 DefaultLocalPort = 1965;
 
-O0BaseAuth::O0BaseAuth(QObject *parent): QObject(parent)
+O0BaseAuth::O0BaseAuth(QObject *parent) : QObject(parent)
 {
     localPort_ = DefaultLocalPort;
     store_ = new O0SettingsStore(QString::fromLatin1(O2_ENCRYPTION_KEY), this);
@@ -49,20 +48,20 @@ void O0BaseAuth::setLinked(bool v)
 
 QString O0BaseAuth::tokenSecret()
 {
-    QString key = QString::fromLatin1(O2_KEY_TOKEN_SECRET).arg(clientId_);
+    const QString key = QString::fromLatin1(O2_KEY_TOKEN_SECRET).arg(clientId_);
     return store_->value(key);
 }
 
 void O0BaseAuth::setTokenSecret(const QString &v)
 {
-    QString key = QString::fromLatin1(O2_KEY_TOKEN_SECRET).arg(clientId_);
+    const QString key = QString::fromLatin1(O2_KEY_TOKEN_SECRET).arg(clientId_);
     store_->setValue(key, v);
     Q_EMIT tokenSecretChanged();
 }
 
-QString O0BaseAuth::token()
+QString O0BaseAuth::token() const
 {
-    QString key = QString::fromLatin1(O2_KEY_TOKEN).arg(clientId_);
+    const QString key = QString::fromLatin1(O2_KEY_TOKEN).arg(clientId_);
     return store_->value(key);
 }
 
@@ -73,7 +72,7 @@ void O0BaseAuth::setToken(const QString &v)
     Q_EMIT tokenChanged();
 }
 
-QString O0BaseAuth::clientId()
+QString O0BaseAuth::clientId() const
 {
     return clientId_;
 }
@@ -84,7 +83,7 @@ void O0BaseAuth::setClientId(const QString &value)
     Q_EMIT clientIdChanged();
 }
 
-QString O0BaseAuth::clientSecret()
+QString O0BaseAuth::clientSecret() const
 {
     return clientSecret_;
 }
@@ -95,7 +94,7 @@ void O0BaseAuth::setClientSecret(const QString &value)
     Q_EMIT clientSecretChanged();
 }
 
-int O0BaseAuth::localPort()
+int O0BaseAuth::localPort() const
 {
     return localPort_;
 }
@@ -117,7 +116,7 @@ QVariantMap O0BaseAuth::extraTokens()
     return extraTokens_;
 }
 
-void O0BaseAuth::setExtraTokens(QVariantMap extraTokens)
+void O0BaseAuth::setExtraTokens(const QVariantMap &extraTokens)
 {
     extraTokens_ = extraTokens;
     QByteArray bytes;
