@@ -177,7 +177,7 @@ void O2::link()
         // Save redirect URI, as we have to reuse it when requesting the access token
         redirectUri_ = localhostPolicy_.arg(replyServer_->serverPort());
 
-        // Assemble intial authentication URL
+        // Assemble initial authentication URL
         QList<QPair<QString, QString> > parameters;
         parameters.append(qMakePair(QString(O2_OAUTH2_RESPONSE_TYPE), (grantFlow_ == GrantFlowAuthorizationCode) ? QString(O2_OAUTH2_GRANT_TYPE_CODE) : QString(O2_OAUTH2_GRANT_TYPE_TOKEN)));
         parameters.append(qMakePair(QString(O2_OAUTH2_CLIENT_ID), clientId_));
@@ -319,7 +319,7 @@ QByteArray O2::buildRequestBody(const QMap<QString, QString> &parameters)
 {
     QByteArray body;
     bool first = true;
-    foreach (const QString &key, parameters.keys()) {
+    for (const QString &key : parameters.keys()) {
         if (first) {
             first = false;
         } else {
