@@ -33,7 +33,7 @@
 #include <ksslinfodialog.h>
 #include <kwindowsystem.h>
 #include <QSslCipher>
-#include <QtDBus/QDBusConnection>
+#include <QDBusConnection>
 
 using namespace Akonadi;
 
@@ -42,8 +42,8 @@ TomboyNotesResource::TomboyNotesResource(const QString &id)
 {
     new SettingsAdaptor(Settings::self());
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/Settings"),
-            Settings::self(),
-            QDBusConnection::ExportAdaptors);
+                                                 Settings::self(),
+                                                 QDBusConnection::ExportAdaptors);
 
     // Akonadi:Item should always provide the payload
     changeRecorder()->itemFetchScope().fetchFullPayload(true);
@@ -51,7 +51,7 @@ TomboyNotesResource::TomboyNotesResource(const QString &id)
     // Status message stuff
     mStatusMessageTimer = new QTimer(this);
     mStatusMessageTimer->setSingleShot(true);
-    connect(mStatusMessageTimer, &QTimer::timeout, [ = ]() {
+    connect(mStatusMessageTimer, &QTimer::timeout, [=]() {
         Q_EMIT status(Akonadi::AgentBase::Idle, QString());
     });
     connect(this, &AgentBase::error, this, &TomboyNotesResource::showError);
@@ -77,7 +77,12 @@ void TomboyNotesResource::retrieveCollections()
         return;
     }
 
-    auto job = new TomboyCollectionsDownloadJob(Settings::collectionName(), mManager, this);
+    int refreshInterval = Settings::self()->refreshInterval();
+    if (refreshInterval == 0) {
+        refreshInterval = -1;
+    }
+
+    auto job = new TomboyCollectionsDownloadJob(Settings::collectionName(), mManager, refreshInterval, this);
     job->setAuthentication(Settings::requestToken(), Settings::requestTokenSecret());
     job->setServerURL(Settings::serverURL(), Settings::userURL());
     // connect to its result() signal
